# Qyout - say "cute" - Qt Youtube Downloader HMI

Install:
``` bash
# create a venv
python3 -m venv venv
. activate venv/bin/activate
pip install --upgrade pip
pip install qyout
```

Run:
``` bash
. venv/bin/activate
qyout

# or
./venv/bin/qyout
```

Enjoy :)


# For developers

Todo list:
* Add a logger
* Use a config parser and allow user config
* Beautifully the GUI
* Add download options


Build wheel from sources:
``` bash
# clone repository
git clone https://github.com/Guitouu31/qyout.git

./deliver.sh
```


Test:
``` bash
# deliver and install
./test.sh
```
